<?php
/* $Id: estonian-iso-8859-1.inc.php,v 2.75 2005/03/30 19:21:39 lem9 Exp $ */

$charset = 'iso-8859-1';
$text_dir = 'ltr'; // ('ltr' for left to right, 'rtl' for right to left)
$left_font_family = 'verdana, arial, helvetica, geneva, sans-serif';
$right_font_family = 'arial, helvetica, geneva, sans-serif';
$number_thousands_separator = ',';
$number_decimal_separator = '.';
// shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
$byteUnits = array('Baiti', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB');

$day_of_week = array('Ph', 'Esm', 'Tei', 'Kol', 'Nel', 'Ree', 'Lau');
$month = array('Jan', 'Veb', 'Mr', 'Apr', 'Mai', 'Jun', 'Jul', 'Aug', 'Sep', 'Okt', 'Nov', 'Det');
// See http://www.php.net/manual/en/function.strftime.php to define the
// variable below
$datefmt = '%d.%m.%Y kell %H:%M:%S';
$timespanfmt = '%s peva, %s tundi, %s minutit ja %s sekundit';

$strAPrimaryKey = 'Primaarne vti lisati %s';
$strAbortedClients = 'Katkestatud';
$strAbsolutePathToDocSqlDir = 'Palun sisestage absoluutne tee webiserveris docSQL kataloogini';
$strAccessDenied = 'Ligips keelatud';
$strAccessDeniedExplanation = 'phpMyAdmin proovis henduda MySQL serveriga ja server lkkas henduse tagasi. Te peaksite kontrollima serverit, kasutajanime ja parooli config.inc.php failis ning kontrollima, et need vastaks infole mis te saite oma MySQL serveri administraatori kest.';
$strAction = 'Tegevus';
$strAddAutoIncrement = 'Lisa AUTO_INCREMENT vrtus';
$strAddConstraints = 'Lisa piirangud';
$strAddDeleteColumn = 'Lisa/Kustuta vlja veerud';
$strAddDeleteRow = 'Lisa/Kustuta kriteeriumirida';
$strAddDropDatabase = 'Lisa DROP DATABASE';
$strAddFields = 'Lisa %s vli(jad)';
$strAddHeaderComment = 'Lisa vaba kommentaar pisesse (\\n eraldab read)';
$strAddIfNotExists = 'Lisa IF NOT EXISTS';
$strAddIntoComments = 'Lisa kommentaaridesse';
$strAddNewField = 'Lisa uus vli';
$strAddPrivilegesOnDb = 'Lisa privileegid antud andmebaasile';
$strAddPrivilegesOnTbl = 'Lisa privileegid antud tabelile';
$strAddSearchConditions = 'Lisa otsinguparameetrid ("WHERE" lause sisu):';
$strAddToIndex = 'Lisa indeksisse &nbsp;%s&nbsp;rida/read';
$strAddUser = 'Lisa uus kasutaja';
$strAddUserMessage = 'Te lisasite uue kasutaja.';
$strAddedColumnComment = 'Kommentaar lisatud vljale';
$strAddedColumnRelation = 'Sltuvus lisatud vljale';
$strAdministration = 'Administreerimine';
$strAffectedRows = 'Mjutatud read:';
$strAfter = 'Peale %s';
$strAfterInsertBack = 'Mine eelmisele lehele tagasi';
$strAfterInsertNewInsert = 'Lisa jrgmine uus rida';
$strAfterInsertNext = 'Muuda jrgmist rida';
$strAfterInsertSame = 'Mine tagasi sellele lehele';
$strAll = 'Kik';
$strAllTableSameWidth = 'kuva kik tabelid sama laiusega?';
$strAlterOrderBy = 'Muuda tabeli sorteeringut';
$strAnIndex = 'Indeks lisati %s';
$strAnalyzeTable = 'Analsi tabelit';
$strAnd = 'ja';
$strAny = 'kik';
$strAnyHost = 'Kik masinad';
$strAnyUser = 'Kik kasutajad';
$strApproximateCount = 'Vib olla umbkaudne. Vaadake FAQ 3.11';
$strArabic = 'Araabia';
$strArmenian = 'Armeenia';
$strAscending = 'Kasvav';
$strAtBeginningOfTable = 'Tabeli algusesse';
$strAtEndOfTable = 'Tabeli lppu';
$strAttr = 'Parameetrid';
$strAutodetect = 'Automaatne tuvastus';
$strAutomaticLayout = 'Automaatne vljund';

$strBack = 'Tagasi';
$strBaltic = 'Balti';
$strBeginCut = 'ALUSTA LIGET';
$strBeginRaw = 'ALUSTA PUHAST';
$strBinLogEventType = 'Sndmuse tp';
$strBinLogInfo = 'Informatsioon';
$strBinLogName = 'Logi nimi';
$strBinLogOriginalPosition = 'Originaal positioon';
$strBinLogPosition = 'Positsioon';
$strBinLogServerId = 'Serveri ID';
$strBinary = 'Binaarne';
$strBinaryDoNotEdit = 'Binaarne - rge muutke';
$strBinaryLog = 'Binaarne logi';
$strBookmarkAllUsers = 'Anna kikidele kasutajatele juurdeps sellele jrjehodjale';
$strBookmarkDeleted = 'Jrjehodja kustutati.';
$strBookmarkLabel = 'Nimetus';
$strBookmarkOptions = 'Jrjehoidja seaded';
$strBookmarkQuery = 'Jrjehodjaga SQL pring';
$strBookmarkThis = 'Lisa see SQL pring jrjehoidjasse';
$strBookmarkView = 'Vaata ainult';
$strBrowse = 'Vaata';
$strBrowseForeignValues = 'Vaata vliseid vrtuseid';
$strBulgarian = 'Bulgaaria';
$strBzError = 'phpMyAdmin ei suutnud pakkida seda andmebaasivljundit kuna Bz2 moodul on vigane selles PHP versioonis. Me soovitame tungivalt oma phpMyAdmini konfiguratsioonifailis panna lipu <code>$cfg[\'BZipDump\']</code> vrtuseks <code>FALSE</code>. Kui te soovite kasutada Bz2 pakkimist peaksite te oma PHP versiooni uuendama viimasele versioonile. Lugege PHP vea %s raportit tpsemaks infoks.';
$strBzip = '"bzipitud"';

$strCSVOptions = 'CSV seaded';
$strCalendar = 'Kalender';
$strCannotLogin = 'Eei suuda MySQL serverisse logida';
$strCantLoad = 'ei suutnud lugeda moodulit %s,<br />palun kontrollige PHP konfiguratsiooni';
$strCantLoadRecodeIconv = 'Ei suuda lugeda iconv vi recode moodulit mida on vaja thetabeli konvertimiseks, konfigureerige PHP-d nii, et see sisaldaks antud mooduleid vi keelake thetabeli konvertimine phpMyAdminis.';
$strCantRenameIdxToPrimary = 'Ei suuda muuta indeksit PRIMAARSEKS!';
$strCantUseRecodeIconv = 'Ei suuda kasutada iconv-d vi libiconvi vi recode_string funktsiooni kuigi moodul on installitud Kontrollige oma PHP konfiguratsiooni.';
$strCardinality = 'Kasulikkus';
$strCarriage = 'Reavahetus: \\r';
$strCaseInsensitive = 'tstutundetu';
$strCaseSensitive = 'tstutundlik';
$strCentralEuropean = 'Kesk-Euroopa';
$strChange = 'Muuda';
$strChangeCopyMode = 'Loo uus kasutaja samade privileegidega ja ...';
$strChangeCopyModeCopy = '... hoia vana alles.';
$strChangeCopyModeDeleteAndReload = ' ... kustuta vana kasutajate tabelist ja taaslae privileegid prast seda.';
$strChangeCopyModeJustDelete = ' ... kustuta vana kasutajate tabelist.';
$strChangeCopyModeRevoke = ' ... kanna kik aktiivsed privileegid le vanast ja kustuta see prast.';
$strChangeCopyUser = 'Vaheta logimisinformatsiooni / Kopeeri kasutaja';
$strChangeDisplay = 'Vali vli mida kuvada';
$strChangePassword = 'Muuda parooli';
$strCharset = 'Thetabel';
$strCharsetOfFile = 'Faili thetabel:';
$strCharsets = 'Thetabelid';
$strCharsetsAndCollations = 'Thetabelid ja mrangud';
$strCheckAll = 'Mrgista kik';
$strCheckOverhead = 'Kontrolli lekulusid';
$strCheckPrivs = 'Kontrollige privileege';
$strCheckPrivsLong = 'Kontrolli privileege andmebaasile &quot;%s&quot;.';
$strCheckTable = 'Kontrolli tabelit';
$strChoosePage = 'Palun valige leht muutmiseks';
$strColComFeat = 'Nitan veeru kommentaare';
$strCollation = 'Mrang';
$strColumnNames = 'Vljade nimed';
$strColumnPrivileges = 'Vli-spetsiifilised privileegid';
$strCommand = 'Ksk';
$strComments = 'Kommentaarid';
$strCommentsForTable = 'KOMMENTAARID TABELILE';
$strCompatibleHashing = 'MySQL&nbsp;4.0-iga hilduv';
$strCompleteInserts = 'Tispikk INSERT';
$strCompression = 'Pakkimine';
$strConfigFileError = 'phpMyAdmin ei suutnud lugeda Teie konfiguratsioonifaili!<br />See vib juhtuda kui PHP leiab vea selles vi PHP ei leia antud faili les.<br />Palun kutsuge konfiguratsioonifail vlja otseselt kasutades linki allpool ja lugege PHP veateadet(eid) mis teile eldakse. Enamustel juhtudel on kuskilt puudu lakoma vi semikoolon.<br />Kui Teile kuvatakse thi leht on kik korras.';
$strConfigureTableCoord = 'Palun seadke koordinaadid tabelile %s';
$strConnectionError = 'Ei saa hendust: vigased seaded.';
$strConnections = 'hendused';
$strConstraintsForDumped = 'Piirangud salvestatud tabelitele';
$strConstraintsForTable = 'Piirangud tabelile';
$strCookiesRequired = 'Kpsised(cookies) peavad alates sellest momendist lubatud olema.';
$strCopyDatabaseOK = 'Andmebaas %s on kopeeritud %s';
$strCopyTable = 'Kopeeri tabel (andmebaas<b>.</b>tabel):';
$strCopyTableOK = 'Tabel %s on kopeeritud andmebaasi %s.';
$strCopyTableSameNames = 'Ei saa tabelit iseendasse kopeerida!';
$strCouldNotKill = 'phpMyAdmin ei suutnud katkestada protsessi %s. Tenoliselt on see juba suletud.';
$strCreate = 'Loo';
$strCreateIndex = 'Loo indeks &nbsp;%s&nbsp;vljadest';
$strCreateIndexTopic = 'Loo uus indeks';
$strCreateNewDatabase = 'Loo uus andmebaas';
$strCreateNewTable = 'Loo uus tabel andmebaasi %s';
$strCreatePage = 'Loo uus leht';
$strCreatePdfFeat = 'PDF-ide tegemine';
$strCreationDates = 'Loo/muuda/kontrolli kuupevi';
$strCriteria = 'Kriteerium';
$strCroatian = 'Horvaatia';
$strCyrillic = 'Kirillitsa';
$strCzech = 'Tsehhi';
$strCzechSlovak = 'Tsehhi-Slovaki';

$strDBComment = 'Andmebaasi kommentaar: ';
$strDBCopy = 'Kopeeri andmebaas';
$strDBGContext = 'Sisu';
$strDBGContextID = 'Sisu ID';
$strDBGHits = 'Vajutusi';
$strDBGLine = 'Rida';
$strDBGMaxTimeMs = 'Max aeg, ms';
$strDBGMinTimeMs = 'Min aeg, ms';
$strDBGModule = 'Moodul';
$strDBGTimePerHitMs = 'Aeg/vajutus, ms';
$strDBGTotalTimeMs = 'Koguaeg, ms';
$strDBRename = 'Nimeta andmebaas mber';
$strDanish = 'Taani';
$strData = 'Andmed';
$strDataDict = 'Andmesnastik';
$strDataOnly = 'Ainult andmed';
$strDatabase = 'Andmebaas';
$strDatabaseEmpty = 'Andmebaasi nimi on thi!';
$strDatabaseExportOptions = 'Andmebaasi eksportimise seaded';
$strDatabaseHasBeenDropped = 'Andmebaas %s kustutatud.';
$strDatabaseNoTable = 'See andmebaas ei sisalda tabelit!';
$strDatabases = 'andmebaasid';
$strDatabasesDropped = 'andmebaasid %s kustutati nnestunult.';
$strDatabasesStats = 'Andmebaaside statistika';
$strDatabasesStatsDisable = 'Keelake statistika';
$strDatabasesStatsEnable = 'Lubage statistika';
$strDatabasesStatsHeavyTraffic = 'Mrkus: Lubades siin andmebaasi statistika vite tekitada vga koormava liikuse webiserveri ja MySQL-i vahel.';
$strDbPrivileges = 'Andmebaas-spetsiifilised privileegid';
$strDbSpecific = 'andmebaasiphine';
$strDefault = 'Vaikimisi';
$strDefaultEngine = '%s on vaikimisi varundusmootor sellele MySQL serverile.';
$strDefaultValueHelp = 'Vaikimisi vrtuse jaoks sisestage lihtsalt ksik vrtus, ilma kaldkriipsudega varjestamata ning jutumrkideta, kasutades jrgmist kirjakuju: a';
$strDefragment = 'Defrgamenteeri tabel';
$strDelOld = 'Antud lehel on viiteid tabelitele mida enam ei ole. Kas te soovite kustutada need viited?';
$strDelayedInserts = 'Kasuta ajastatud lisamisi';
$strDelete = 'Kustuta';
$strDeleteAndFlush = 'Kustutage kasutajad ja taaslaadige privileegid prast seda.';
$strDeleteAndFlushDescr = 'See on parim tee, kuid privileegide taaslaadimine vib vtta aega.';
$strDeleted = 'Rida kustutatud';
$strDeletedRows = 'Kustuta read:';
$strDeleting = 'Kustutan %s';
$strDescending = 'Kahanev';
$strDescription = 'Kirjeldus';
$strDictionary = 'snaraamat';
$strDisableForeignChecks = 'Keela foreign keyde kontroll';
$strDisabled = 'Keelatud';
$strDisplayFeat = 'Kuva vimalused';
$strDisplayOrder = 'Nitamise jrjekord:';
$strDisplayPDF = 'Nita PDF skeemi';
$strDoAQuery = 'Tee "pring nite jrgi" (lhend: "%")';
$strDoYouReally = 'Kas te testi tahate ';
$strDocu = 'Dokumentatsioon';
$strDrop = 'Kustuta';
$strDropDatabaseStrongWarning = 'Thelepanu! Te HVITATE kogu andmebaasi!';
$strDropSelectedDatabases = 'Kustutage valitud andmebaasid';
$strDropUsersDb = 'Kustuta andmebaasid millel on samad nimed nagu kasutajatel.';
$strDumpSaved = 'Vljavte salvestati faili %s.';
$strDumpXRows = 'Pri %s rida alustades reast %s.';
$strDumpingData = 'Tabeli andmete salvestamine';
$strDynamic = 'dnaamiline';

$strEdit = 'Muuda';
$strEditPDFPages = 'Muuda PDF lehti';
$strEditPrivileges = 'Muuda privileege';
$strEffective = 'Efektiivne';
$strEmpty = 'Thjenda';
$strEmptyResultSet = 'MySQL tagastas thja tulemuse (s.t. null rida).';
$strEnabled = 'Lubatud';
$strEncloseInTransaction = 'Lisa eksport lekandesse';
$strEnd = 'Lpp';
$strEndCut = 'LPETA LIGE';
$strEndRaw = 'LPETA PUHAS';
$strEngineAvailable = '%s on saadaval selles MySQL serveris.';
$strEngineDisabled = '%s on keelatud selles MySQL serveris.';
$strEngineUnsupported = 'See MySQL server ei toeta %s varundusmootorit.';
$strEngines = 'Mootor';
$strEnglish = 'Inglise';
$strEnglishPrivileges = ' Mrkus: MySQL privileegide nimed on ingliskeelsed ';
$strError = 'Viga';
$strEscapeWildcards = 'Metamrgid _ ja % peaksid olema varjestatud mrgiga \, kui soovite neid sisestada';
$strEstonian = 'Eesti';
$strExcelEdition = 'Exceli versioon';
$strExcelOptions = 'Excel\'i seaded';
$strExecuteBookmarked = 'Kivita salvestatud pring';
$strExplain = 'Seleta SQL-i';
$strExport = 'Ekspordi';
$strExtendedInserts = 'Laiendatud lisamised';
$strExtra = 'Ekstra';

$strFailedAttempts = 'Ebannestunud ritused';
$strField = 'Vli';
$strFieldHasBeenDropped = 'Vli %s kustutatud';
$strFields = 'Vljade arv';
$strFieldsEmpty = ' Vljade loetelu on thi! ';
$strFieldsEnclosedBy = 'Vljad mbritsetud';
$strFieldsEscapedBy = 'Vljad varjatud';
$strFieldsTerminatedBy = 'Vljad eraldatud';
$strFileAlreadyExists = 'Fail %s on juba serveris olemas, muutke faili nime vi kontrollige lekirjutamise seadeid.';
$strFileCouldNotBeRead = 'Faili ei suudetud lugeda';
$strFileNameTemplate = 'Faili nime template';
$strFileNameTemplateHelp = 'Kasutage __DB__ andmebaasi nime jaoks, __TABLE__ tabeli nime jaoks ja %skskik milliseid strftime%s seadeid aja mramiseks, moodul lisatakse automaatselt. lejnud teksti ei muudeta.';
$strFileNameTemplateRemember = 'jta template meelde';
$strFixed = 'parandatud';
$strFlushPrivilegesNote = 'Mrkus: phpMyAdmin vtab kasutajate privileegid otse MySQL privileges tabelist. Tabeli sisu vib erineda sellest, mida server hetkel kasutab, seda juhul kui olete ksitsi muudatusi teinud. Sellisel juhul peaksite te privileegid %staaslaadima%s enne jtkamist.';
$strFlushTable = 'htlusta tabelid ("FLUSH")';
$strFormEmpty = 'Puuduv vrtus vormis !';
$strFormat = 'Formaat';
$strFullText = 'Tistekstid';
$strFunction = 'Funktsioon';

$strGenBy = 'Genereerija ';
$strGenTime = 'Tegemisaeg';
$strGeneralRelationFeat = 'Peamised seoste vimalused';
$strGeorgian = 'Gruusia';
$strGerman = 'Saksa';
$strGlobal = 'globaalne';
$strGlobalPrivileges = 'Globaalsed privileegid';
$strGlobalValue = 'ldine vrtus';
$strGo = 'Mine';
$strGrantOption = 'igused';
$strGreek = 'Kreeka';
$strGzip = '"gzipitud"';

$strHasBeenAltered = 'on muudetud.';
$strHasBeenCreated = 'on loodud.';
$strHaveToShow = 'Te peate valima vhemalt he veeru kuvamiseks';
$strHebrew = 'Heebrea';
$strHexForBinary = 'Kasuta 16nd koodi binaarvljades';
$strHome = 'Esileht';
$strHomepageOfficial = 'Ametlik phpMyAdmini koduleht';
$strHost = 'Masin';
$strHostEmpty = 'Masin on thi!';
$strHungarian = 'Ungari';

$strIcelandic = 'Islandi';
$strId = 'ID';
$strIdxFulltext = 'Tistekst';
$strIfYouWish = 'Kui soovite lugeda ainult mningaid tabeli vlju, sisestage komaga eraldatud vljade loetelu.';
$strIgnore = 'Ignoreeri';
$strIgnoreInserts = 'Kasutaja ignoreeritavaid lisamisi';
$strIgnoringFile = 'Jtan vahele faili %s';
$strImportDocSQL = 'docSQL failide importimine';
$strImportFiles = 'Importige failid';
$strImportFinished = 'Import lpetatud';
$strInUse = 'kasutusel';
$strIndex = 'Indeks';
$strIndexHasBeenDropped = 'Indeks %s kustutatud';
$strIndexName = 'Indeksi nimi&nbsp;:';
$strIndexType = 'Indeksi tp&nbsp;:';
$strIndexWarningMultiple = 'Rohkem kui ks %s vti loodi vljale `%s`';
$strIndexWarningPrimary = 'PRIMARY ja INDEX vtmed ei tohiks mlemad olla mratud vljale `%s`';
$strIndexWarningTable = 'Probleemid tabeli `%s` indeksitega';
$strIndexWarningUnique = 'UNIQUE ja INDEX ei tohiks mlemad olla mratud vljale `%s`';
$strIndexes = 'Indeksid';
$strInnodbStat = 'InnoDB staatus';
$strInsecureMySQL = 'Teie konfiguratsioonifail sisaldab seadeid (root kasutaja ilma paroolita) mis vastab MySQL-i vaikimisi priviligeeritud kasutajale. Kui Teie MySQL-i server jookseb sellise seadega on ta avatud rnnakutele, soovitav on see turvaauk kiiresti parandada.';
$strInsert = 'Lisa';
$strInsertAsNewRow = 'Lisa uue reana';
$strInsertBookmarkTitle = 'Palun sisestage jrjehoidja pealkiri';
$strInsertNewRow = 'Lisa uus rida';
$strInsertTextfiles = 'Lisa andmed tekstifailist tabelisse';
$strInsertedRowId = 'Lisatud rea id:';
$strInsertedRows = 'Lisatud read:';
$strInstructions = 'sisestust';
$strInternalNotNecessary = '* Sisene seos ei ole vajalik kui ta eksisteerib ka InnoDB-s.';
$strInternalRelations = 'Sisesed seosed';

$strJapanese = 'Jaapani';
$strJumpToDB = 'Hppa andmebaasile &quot;%s&quot;.';
$strJustDelete = 'Lihtsalt kustutage kasutajad privilege tabelist.';
$strJustDeleteDescr = '&quot;Kustutatud&quot; kasutajad vivad ikka veel ligi pseda serverile, kuni privileegid pole uuesti sisse loetud.';

$strKeepPass = 'rge muutke parooli';
$strKeyname = 'Vtme nimi';
$strKill = 'Tapa';
$strKorean = 'Korea';

$strLaTeX = 'LaTeX';
$strLaTeXOptions = 'LaTeX\'i seaded';
$strLandscape = 'Laipilt';
$strLatexCaption = 'Tabeli seletus';
$strLatexContent = 'Tabeli __TABLE__ sisu';
$strLatexContinued = '(jtkub)';
$strLatexContinuedCaption = 'Jtkuva tabeli seletus';
$strLatexIncludeCaption = 'Lisa tabeli seletus';
$strLatexLabel = 'Nimetuse vti';
$strLatexStructure = 'Tabeli __TABLE__ struktuur';
$strLatvian = 'Lti';
$strLengthSet = 'Pikkus/Vrtused*';
$strLimitNumRows = 'Ridade arv lehel';
$strLineFeed = 'Realpp: \\n';
$strLinesTerminatedBy = 'Read lpetatud';
$strLinkNotFound = 'Linki ei leitud';
$strLinksTo = 'Lingib ';
$strLithuanian = 'Leedu';
$strLoadExplanation = 'Vaikimisi on aktiivne parim meetod aga te vite seda muuta, kui see ei tta.';
$strLoadMethod = 'LOAD meetod';
$strLocalhost = 'Lokaalne';
$strLocationTextfile = 'tekstifaili asukoht';
$strLogPassword = 'Parool:';
$strLogServer = 'Server';
$strLogUsername = 'Kasutajanimi:';
$strLogin = 'Sisselogimine';
$strLoginInformation = 'Logimise informatsioon';
$strLogout = 'Logi vlja';
$strLongOperation = 'See tegevus vib vtta kaua aega. Jtkan?';

$strMIMETypesForTable = 'MIME TBID TABELILE';
$strMIME_MIMEtype = 'MIME-tp';
$strMIME_available_mime = 'Olemasolevad MIME-tbid';
$strMIME_available_transform = 'Available transformations';
$strMIME_description = 'Kirjeldus';
$strMIME_nodescription = 'Selle transformatsiooni jaoks ei ole kirjeldust.<br />Palun ksige autorilt, mida %s teeb.';
$strMIME_transformation = 'Browseri transformatsioon';
$strMIME_transformation_note = 'Transformatsiooni vimaluste ja tema MIME-tbi transformatsiooni nimekirjaks vajutage %stransformatsiooni kirjeldusele%s';
$strMIME_transformation_options = 'Transformeerimise seaded';
$strMIME_transformation_options_note = 'Palun sisestage transformatsiooniks vajalikud vrtused, kasutades jrgmist formaati: \'a\',\'b\',\'c\'...<br />Kui teil on vaja edastada kaldkriips ("\") vi lakoma ("\'") nende vrtuste seas, varjestage see tagurpidi kaldkriipsuga (niteks \'\\\\xyz\' vi \'a\\\'b\').';
$strMIME_without = 'MIME-tbid kursiivis ei oma eraldi transofrmatsiooni funktsiooni';
$strMaximumSize = 'Maksimaalne suurus: %s%s';
$strMbExtensionMissing = 'Ei leitud mbstring PHP lisa ja tundub, et te kasutate mitmebaidilist thetabelit. Ilma mbstring lisata ei suuda phpMyAdmin poolitada teksti korrektselt ja tulemus vib olla ootustele mittevastav.';
$strMbOverloadWarning = 'Te olete lubanud mbstring.func_overload oma PHP konfiguratsioonis. See seade ei hildu phpMyAdminiga ja vib osade andmete kadumist phjustada!';
$strModifications = 'Muutused salvestatud';
$strModify = 'Muuda';
$strModifyIndexTopic = 'Muuda indeksit';
$strMoreStatusVars = 'Rohkem staatusevrtusi';
$strMoveTable = 'Vii tabel le (andmebaas<b>.</b>tabel):';
$strMoveTableOK = 'Tabel %s viidu le andmebaasi %s.';
$strMoveTableSameNames = 'Ei saa tabelit iseendasse liigutada!';
$strMultilingual = 'mitmekeelne';
$strMustSelectFile = 'Palun valige fail mida soovite lisada.';
$strMyISAMDataPointerSize = 'Andmeviida suurus';
$strMyISAMDataPointerSizeDesc = 'Vaikimisi viida suurus baitides, mida kasutatakse CREATE TABLE ksuga MyISAM tabelite jaoks kui MAX_ROWS seade on mramata.';
$strMyISAMMaxExtraSortFileSize = 'Maksimaalne failisuurus ajutiste failide jaoks indeksi genereerimisel';
$strMyISAMMaxExtraSortFileSizeDesc = 'Kui ajutine fail mida kasutatakse kiire MyISAM indeksi loomiseks on suurem kui kasutada siin mratud vtmecache suurust, siis eelistage vtmecache meetodit.';
$strMyISAMMaxSortFileSize = 'Maksimaalne suurus ajutiste sorteeringufailide jaoks';
$strMyISAMMaxSortFileSizeDesc = 'Maksimaalne failisuurus MySQL-i ajutise faili jaoks mida kasutatakse MyISAM indeksi uuesti genereerimiseks (REPAIR TABLE, ALTER TABLE vi LOAD DATA INFILE).';
$strMyISAMRecoverOptions = 'Automaatne taastamine';
$strMyISAMRecoverOptionsDesc = 'Automaatne taastamine purunenud MyISAM tabelitele, aktiveeritakse vtmega --myisam-recover serveri kivitamisel.';
$strMyISAMRepairThreads = 'Paranda limud';
$strMyISAMRepairThreadsDesc = 'Kui see vrtus on suurem kui 1 siis MyISAM tabeli indeksid luuakse paralleelselt (iga indeks oma limus) sorteerimise teel parandamise ajal.';
$strMyISAMSortBufferSize = 'Sordi puhvri suurus';
$strMyISAMSortBufferSizeDesc = 'Puhver mis hivatakse kui sorteeritakse MyISAM indekseid REPAIR TABLE ajal vi kui luuakse indekseid CREATE INDEX vi ALTER TABLE kskudega.';
$strMySQLCharset = 'MySQLi thetabel';
$strMySQLConnectionCollation = 'MySQL henduse kollatsioon';
$strMySQLReloaded = 'MySQL uuesti laetud.';
$strMySQLSaid = 'MySQL tles: ';
$strMySQLServerProcess = 'MySQL %pma_s1% jookseb %pma_s2%\'is - %pma_s3%';
$strMySQLShowProcess = 'Nita protsesse';
$strMySQLShowStatus = 'Nita MySQL-i jooksvat informatsiooni';
$strMySQLShowVars = 'Nita MySQL ssteemseid muutujaid';

$strName = 'Nimi';
$strNeedPrimaryKey = 'Te peaksite defineerima primaarse vtme sellele tabelile.';
$strNext = 'Jrgmine';
$strNo = 'Ei';
$strNoActivity = 'Ebaaktiivne %s sekundit vi rohkem, palun sisenege uuesti';
$strNoDatabases = 'Pole andmebaase';
$strNoDatabasesSelected = 'htegi andmebaasi ei ole valitud.';
$strNoDescription = 'pole kirjeldust';
$strNoDetailsForEngine = 'Detailne seisuinformatsioon antud varundusmootori kohta puudub.';
$strNoDropDatabases = '"DROP DATABASE" ksud keelatud.';
$strNoExplain = 'Jta SQL-i seletamine vahele';
$strNoFrames = 'phpMyAdmin on sbralikum <b>frame toetava</b> browseriga.';
$strNoIndex = 'Indeksit pole defineeritud!';
$strNoIndexPartsDefined = 'Indeksi osad pole defineeritud!';
$strNoModification = 'Ei muudetud';
$strNoOptions = 'Sellel formaadil pole seadeid';
$strNoPassword = 'Ilma paroolita';
$strNoPermission = 'Webiserver ei oma igusi , et salvestada fail %s.';
$strNoPhp = 'ilma PHP koodita';
$strNoPrivileges = 'Ei oma htegi privileegi';
$strNoQuery = 'htegi SQL pringut!';
$strNoRights = 'Teil pole piisavalt igusi, et hetkel siin olla!';
$strNoRowsSelected = 'Ridu pole valitud';
$strNoSpace = 'Liiga vhe kettaruumi, et salvestada fail %s.';
$strNoTablesFound = 'Andmebaasist ei leitud tabeleid.';
$strNoThemeSupport = 'Teemade tugi puudub, palun kontrollige oma seadeid ja/vi oma teemade kataloogi %s.';
$strNoUsersFound = 'Ei leitud htegi kasutajat.';
$strNoValidateSQL = 'Jta SQL-i kontroll vahele';
$strNone = 'Pole';
$strNotNumber = 'See pole number!';
$strNotOK = 'Ei ole korras';
$strNotSet = '<b>%s</b> tabelit ei leitud vi ei eksisteeri %s';
$strNotValidNumber = ' pole korrektne reanumber!';
$strNull = 'Null';
$strNumSearchResultsInTable = '%s vaste(t) tabelis <i>%s</i>';
$strNumSearchResultsTotal = '<b>Kokku:</b> <i>%s</i> vaste(t)';
$strNumTables = 'Tabelid';

$strOK = 'Korras';
$strOftenQuotation = 'Kasuta jutumrke koguaeg. VALIKULISELT thendab, et ainult char ja varchar tpi vljad mbritsetakse mratud mrkidega.';
$strOperations = 'Tegevused';
$strOperator = 'Operaator';
$strOptimizeTable = 'Optimiseeri tabelit';
$strOptionalControls = 'Mittekohustuslik. Kontrollib kuidas kirjutada vi lugeda erimrke.';
$strOptionally = 'VALIKULISELT';
$strOr = 'vi';
$strOverhead = 'lejv';
$strOverwriteExisting = 'Kirjuta olemasolev(ad) fail(id) le';

$strPHP40203 = 'Te kasutate PHP 4.2.3, milles on tsine viga mitmebaidiste tekstidega (mbstring). Vaadake PHP vearaportit 19404. Seda PHP versiooni ei soovitata kasutada phpMyAdminiga.';
$strPHPVersion = 'PHP versioon';
$strPageNumber = 'Lehenumber:';
$strPaperSize = 'Paberi suurus';
$strPartialText = 'Lhendatud tekstid';
$strPassword = 'Parool';
$strPasswordChanged = 'Kasutaja %s parool vahetati nnestunult.';
$strPasswordEmpty = 'Parool on thi!';
$strPasswordHashing = 'Parooli trkimine';
$strPasswordNotSame = 'Paroolid ei hti!';
$strPdfDbSchema = 'Andmebaasi "%s" skeem - leheklg %s';
$strPdfInvalidTblName = '"%s" tabel ei eksisteeri!';
$strPdfNoTables = 'Pole tabeleid';
$strPerHour = 'tunni kohta';
$strPerMinute = 'minutis';
$strPerSecond = 'sekundis';
$strPersian = 'Prsia';
$strPhoneBook = 'telefoniraamat';
$strPhp = 'Loo PHP kood';
$strPmaDocumentation = 'phpMyAdmini dokumentatsioon';
$strPmaUriError = '<tt>$cfg[\'PmaAbsoluteUri\']</tt> konstant peab teie konfiguratsioonifailis mratud olema!';
$strPolish = 'Poola';
$strPortrait = 'Portreepilt';
$strPos1 = 'Algus';
$strPrevious = 'Eelmine';
$strPrimary = 'Primaarne';
$strPrimaryKeyHasBeenDropped = 'Primaarne vti kustutatud';
$strPrimaryKeyName = 'Primaarse vtme nimi peab olema... PRIMARY!';
$strPrimaryKeyWarning = '("PRIMARY" <b>peab</b> olema ja <b>ainult</b> olema primaarse vtme nimi!)';
$strPrint = 'Prindi';
$strPrintView = 'Trkivaade';
$strPrintViewFull = 'Trkivaade (tispikkade tekstidega)';
$strPrivDescAllPrivileges = 'Sisaldab kiki privileege peale GRANT.';
$strPrivDescAlter = 'Lubab muuta olemasolevate tabelite struktuure.';
$strPrivDescCreateDb = 'Lubab luua uusi andmebaase ja tabeleid.';
$strPrivDescCreateTbl = 'Lubab luua uusi tabeleid.';
$strPrivDescCreateTmpTable = 'Lubab luua ajutisi tabeleid.';
$strPrivDescDelete = 'Lubab kustutada infot.';
$strPrivDescDropDb = 'Lubab kustuada andmebaase ja tabeleid.';
$strPrivDescDropTbl = 'Lubab kustutada tabeleid..';
$strPrivDescExecute = 'Lubab kivitada salvestatud protseduure; Ei oma mingit effekti antud MySQL versioonis.';
$strPrivDescFile = 'Lubab andmete eksportimist faili ja andmete importimist failidest.';
$strPrivDescGrant = 'Lubab lisada kasutajaid ja privileege ilma privileges tabelit taaskivitamata.';
$strPrivDescIndex = 'Lubab luua ja kustutada indekseid.';
$strPrivDescInsert = 'Lubab lisada ja muuta infot.';
$strPrivDescLockTables = 'Lubab lukustada tabeleid aktiivse pringu tarbeks.';
$strPrivDescMaxConnections = 'Limiteerib henduste arvu tunnis kasutaja jaoks.';
$strPrivDescMaxQuestions = 'Limiteerib pringute arvu tunnis kasutaja jaoks.';
$strPrivDescMaxUpdates = 'Limiteerib kskude, mis muudavad suvalist tabelit vi andmebaasi, arvu tunnis kasutaja jaoks';
$strPrivDescProcess3 = 'Lubab tappa kasutajate protsesse.';
$strPrivDescProcess4 = 'Lubab vaadata tielikult pringuid protsessitabelis.';
$strPrivDescReferences = 'Ei oma antud MySQL versioonis mingit effekti.';
$strPrivDescReload = 'Lubab taaslaadida serveri seadmeid ja puhastada serveri cachet.';
$strPrivDescReplClient = 'Lubab kasutajal ksida kus on slaved/masterid.';
$strPrivDescReplSlave = 'Vajalik slavede paljundamiseks.';
$strPrivDescSelect = 'Lubab lugeda infot.';
$strPrivDescShowDb = 'Annab ligipsu kogu andmebaasilistingule.';
$strPrivDescShutdown = 'Lubab serverit maha lasta.';
$strPrivDescSuper = 'Lubab henduda, isegi kui maksimaalne henduste arv on saavutatud; Vajalik enamike administratiivsete operatsioonide jaoks, nagu globaalsete muutujate seadmine vi teiste kasutajate henduste tapmine.';
$strPrivDescUpdate = 'Lubab muuta infot.';
$strPrivDescUsage = 'Mitte htegi privileegi.';
$strPrivileges = 'Privileegid';
$strPrivilegesReloaded = 'Privileegid taaslaeti edukalt.';
$strProcesslist = 'Protsessinimekiri';
$strPutColNames = 'Pange vljade nimed esimesse ritta';

$strQBE = 'Pring nite jrgi';
$strQBEDel = 'Del';
$strQBEIns = 'Ins';
$strQueryFrame = 'Pringuaken';
$strQueryOnDb = 'SQL-pring andmebaasist <b>%s</b>:';
$strQuerySQLHistory = 'SQL-ajalugu';
$strQueryStatistics = '<b>Pringu statistika</b>: Alates stardist, %s pringut on saadetud serverile.';
$strQueryTime = 'Pring kestis %01.4f sek';
$strQueryType = 'Pringu tp';
$strQueryWindowLock = 'Antud pringut mitte muuta vljaspool akent.';

$strReType = 'Sisesta uuesti';
$strReceived = 'Saadud';
$strRecords = 'Kirjeid';
$strReferentialIntegrity = 'Kontrolli prinevust:';
$strRefresh = 'Uuenda';
$strRelationNotWorking = 'Lisavimalused ttamiseks lingitud tabelitega on deaktiveeritud. Et lugeda miks see nii on, vajutage %ssiia%s.';
$strRelationView = 'Prinevuse vaade';
$strRelationalSchema = 'Seoseskeem';
$strRelations = 'Suhted';
$strRelationsForTable = 'SEOSED TABELILE';
$strReloadFailed = 'MySQL taaslaadimine ebannestus.';
$strReloadMySQL = 'Taaslae MySQL';
$strReloadingThePrivileges = 'Taaslaen privileege';
$strRemoveSelectedUsers = 'Eemalda valitud kasutajad';
$strRenameDatabaseOK = 'Andmebaas %s on mber nimetatud %s';
$strRenameTable = 'Nimeta tabel mber';
$strRenameTableOK = 'Tabel %s on mber nimetatud %s';
$strRepairTable = 'Paranda tabelit';
$strReplace = 'Asenda';
$strReplaceNULLBy = 'Asenda NULL ';
$strReplaceTable = 'Asenda tabeli andmed failiga';
$strReset = 'Thista';
$strResourceLimits = 'Ressursilimiidid';
$strRevoke = 'Vta tagasi';
$strRevokeAndDelete = 'Eemalda kik aktiivsed privileegid kasutajatelt ning kustuta nad prast seda.';
$strRevokeAndDeleteDescr = 'Kasutajatel on ikka veel USAGE privileeg, kuni privileegid pole taaslaetud.';
$strRevokeMessage = 'Te vtsite tagasi privileegid %s-lt';
$strRomanian = 'Rumeenia';
$strRowLength = 'Rea pikkus';
$strRowSize = ' rea suurus ';
$strRows = 'Ridu';
$strRowsFrom = 'read alates';
$strRowsModeFlippedHorizontal = 'horisontaalne (pratud pis)';
$strRowsModeHorizontal = 'horisontaalselt';
$strRowsModeOptions = 'nita %s and korda pealkirju iga %s jrel';
$strRowsModeVertical = 'vertikaalselt';
$strRowsStatistic = 'Rea statistika';
$strRunQuery = 'Lae pring';
$strRunSQLQuery = 'Pri SQL pring(uid) andmebaasist %s';
$strRunning = 'jookseb masinas %s';
$strRussian = 'Vene';

$strSQL = 'SQL';
$strSQLExportCompatibility = 'SQL ekspordiga hilduvus';
$strSQLExportType = 'Ekspordi tp';
$strSQLOptions = 'SQL seaded';
$strSQLParserBugMessage = 'On vimalus, et te leidsite vea SQL parseris. Palun kontrollige oma pringut tpsemalt ja kontrollige, et jutumrgid/lakomad oleks korrektselt lpetatud. Veel on vimalik, et te loete sisse faili kus on binaarne info vljaspool varjestatud tekstiala. Samuti viksite te proovida oma pringut MySQLi ksureal. MySQLi viga vljastatakse pringu all, kui seal testi on mni viga, siis see vib aidata teil leida vea algphjuseid. Kui teil on peale seda ikka veel probleeme vi kui mu parser keeldub ttamast ning MySQL ksurida ttab, siis palun vhendage oma pringuid ksiku pringuni, mis phjustab probleeme ja sisestage vea raport koos viga phjustanud pringuga LIGET sektsioonis allpool:';
$strSQLParserUserError = 'Tundub, et teie SQL pringus on viga. MySQLi serveri error peaks ilmuma allpool, kui seal on midagi, siis peaks see teil aitama leia vea phjust.';
$strSQLQuery = 'SQL-pring';
$strSQLResult = 'SQL tulemus';
$strSQPBugInvalidIdentifer = 'Vigane identifikaator';
$strSQPBugUnclosedQuote = 'Sulgemata jutumrk/lakoma';
$strSQPBugUnknownPunctuation = 'Tundmatu suunav tekst';
$strSave = 'Salvesta';
$strSaveOnServer = 'Salvestage serverisse kataloogi %s';
$strScaleFactorSmall = 'Skalaarfaktor on liiga vike, et skeem mahuks hele lehele.';
$strSearch = 'Otsi';
$strSearchFormTitle = 'Otsi andmebaasist';
$strSearchInTables = 'Otsi tabeli(te)st:';
$strSearchNeedle = 'Sna(d) vi vrtus(ed) otsinguks (lhend: "%"):';
$strSearchOption1 = 'vhemalt ks snadest';
$strSearchOption2 = 'kik snadest';
$strSearchOption3 = 'tpne fraas';
$strSearchOption4 = 'regulaaravaldisena';
$strSearchResultsFor = 'Otsingu tulemused "<i>%s</i>" %s:';
$strSearchType = 'Leia:';
$strSecretRequired = 'Konfiguratsioonifail nuab nd salajast vtmesna (blowfish_secret).';
$strSelectADb = 'Valige andmebaas';
$strSelectAll = 'Mrgista kik';
$strSelectBinaryLog = 'Valige binaarne logi vaatamiseks';
$strSelectFields = 'Vali vljad (vhemalt ks):';
$strSelectNumRows = 'pringus';
$strSelectTables = 'Vali tabelid';
$strSend = 'Salvesta failina';
$strSent = 'Saadetud';
$strServer = 'Server';
$strServerChoice = 'Serveri valik';
$strServerNotResponding = 'Server ei vasta';
$strServerStatus = 'Jooksev informatsioon';
$strServerStatusUptime = 'See MySQL server on kinud %s. Kivitusaeg %s.';
$strServerTabProcesslist = 'Protsessid';
$strServerTabVariables = 'Muutujad';
$strServerTrafficNotes = '<b>Serveri liiklus</b>: Need tabelid nitavad vrguliikluse statistikat selle MySQL serveri jaoks alates tema kivitamisest.';
$strServerVars = 'Serveri muutujad ja seaded.';
$strServerVersion = 'Serveri versioon';
$strSessionValue = 'Sessiooni vrtus';
$strSetEnumVal = 'Kui vlja tp on "enum" vi "set", palun sisestage vrtused kasutades jrgmist paigutust: \'a\',\'b\',\'c\'...<br />Kui te peate lisama kaldkriipsu ("\") vi lakoma ("\'") sinna paigutusse, varjestage see tagurpidi kaldkriipsuga (niteks \'\\\\xyz\' vi \'a\\\'b\').';
$strShow = 'Nita';
$strShowAll = 'Nita kiki';
$strShowColor = 'Nita vrvi';
$strShowDatadictAs = 'Andmesnastiku formaat';
$strShowFullQueries = 'Nita tispikkasid pringuid';
$strShowGrid = 'Nita vrgustiku';
$strShowPHPInfo = 'Nita PHP informatsiooni';
$strShowTableDimension = 'Nita tabelite dimensiooni';
$strShowTables = 'Nita tabeleid';
$strShowThisQuery = ' Nita pringut siin uuesti ';
$strShowingRecords = 'Nita ridu';
$strSimplifiedChinese = 'Lihtsustatud Hiina';
$strSingly = '(ksikult)';
$strSize = 'Suurus';
$strSlovak = 'Slovaki';
$strSlovenian = 'Sloveenia';
$strSort = 'Sorteeri';
$strSortByKey = 'Sorteeri vtme jrgi';
$strSpaceUsage = 'Ruumivtt';
$strSpanish = 'Hispaania';
$strSplitWordsWithSpace = 'Snad on eraldatud thikuga (" ").';
$strStatCheckTime = 'Viimane vaatamine';
$strStatCreateTime = 'Loodud';
$strStatUpdateTime = 'Viimane muudatus';
$strStatement = 'Parameerid';
$strStatus = 'Staatus';
$strStorageEngine = 'Varundusmootor';
$strStorageEngines = 'Varundusmootorid';
$strStrucCSV = 'CSV andmed';
$strStrucData = 'Struktuur ja andmed';
$strStrucDrop = 'Lisa DROP TABLE';
$strStrucExcelCSV = 'CSV MS Exceli jaoks';
$strStrucNativeExcel = 'Loomulikud MS Exceli andmed';
$strStrucOnly = 'Ainult struktuur';
$strStructPropose = 'Soovita tabeli struktuuri';
$strStructure = 'Struktuur';
$strSubmit = 'Vali';
$strSuccess = 'Teie SQL pring tideti edukalt';
$strSum = 'Summa';
$strSwedish = 'Rootsi';
$strSwitchToDatabase = 'Mine kopeeritud andmebaasile';
$strSwitchToTable = 'Mine le kopeeritud tabelile';

$strTable = 'Tabel';
$strTableComments = 'Tabeli kommentaarid';
$strTableEmpty = 'Tabeli nimi on thi!';
$strTableHasBeenDropped = 'Tabel %s kustutatud';
$strTableHasBeenEmptied = 'Tabel %s thjendatud';
$strTableHasBeenFlushed = 'Tabel %s htlustatud';
$strTableMaintenance = 'Tabeli hooldus';
$strTableOfContents = 'Sisukord';
$strTableOptions = 'Tabeli seaded';
$strTableStructure = 'Struktuur tabelile';
$strTableType = 'Tabeli tp';
$strTables = '%s tabel(it)';
$strTakeIt = 'vta see';
$strTblPrivileges = 'Tabel-spetsiifilised privileegid';
$strTextAreaLength = ' Oma suuruse tttu<br /> vib see vli olla mittemuudetav ';
$strThai = 'Tai';
$strTheContent = 'Teie faili sisu on lisatud.';
$strTheContents = 'Faili sisu asendab valitud tabeli sisu ridades kus on identsed primaarsed vi unikaalsed vtmed.';
$strTheTerminator = 'Vljade eraldaja.';
$strTheme = 'Teema / Stiil';
$strThisHost = 'Antud host';
$strThisNotDirectory = 'See ei olnud kataloog';
$strThreadSuccessfullyKilled = 'Protsess %s katkestati edukalt.';
$strTime = 'Aeg';
$strToggleScratchboard = 'vaheta mrkmetahvlit';
$strTotal = 'kokku';
$strTotalUC = 'Kokku';
$strTraditionalChinese = 'Traditsionaalne Hiina';
$strTraditionalSpanish = 'Traditsionaalne Hispaania';
$strTraffic = 'Liiklus';
$strTransformation_application_octetstream__download = 'Nita linki millega laadida alla vlja binaarne info. Esimene seade on binaarse faili nimi. Teine seade on vimalik vljanimi tabelis mis sisaldab failinime. Kui te mrate teise seade siis peab esimene seade olema thi tekst';
$strTransformation_image_jpeg__inline = 'Kuvab lingitud vikepildi; seaded: laius,krgus pikslites (hoiab alles originaalpildi laiuse-krguse suhte)';
$strTransformation_image_jpeg__link = 'Kuvab lingi sellele pildile (otsene binaarne allalaadimine, jne.).';
$strTransformation_image_png__inline = 'Vaata image/jpeg: inline';
$strTransformation_text_plain__dateformat = 'Vtab TIME, TIMESTAMP vi DATETIME tpi vlja ja teisendab selle Teie lokaalse ajaseade jrgi. Esimene seade on lisa (tundides) , mis lisatakse ajale (vaikimisi: 0). Teine seade on teistsugune ajamrang vastavalt PHP  strftime() funktsioonile.';
$strTransformation_text_plain__external = 'AINULT LINUXILE: Kivitab vlise aplikatsiooni ja annab talle standard sisendisse ette vlja sisu. Tagastab aplikatsiooni standard vljundi. Vaikimisi on selleks Tidy, et kuvada ilusti formaaditud HTML koodi. Turvariskide maandamiseks peate te ksitsi muutma faili libraries/transformations/text_plain__external.inc.php ja lisama sinna programmid mida te lasete kivitada. Esimene seade on siis kasutatava programmi number, teine seade on programmi parameetrid. Kui kolmas seade on 1 siis tdeldakse vljund funktsiooniga htmlspecialchars() (vaikimisi 1). Kui neljas seade on  1 pannakse NOWRAP sisu lahtrile nii, et kogu vljund kuvatakse ilma formaati muutmata(vaikimisi 1)';
$strTransformation_text_plain__formatted = 'Hoiab alles originaalset vlja formaati. Ei varjestata.';
$strTransformation_text_plain__imagelink = 'Kuvab pildi ja lingi, vli sisaldab failinime; esimene seade on eelnev tekst nagu "http://domain.com/", teine seade on laius pikslites, kolmas on krgus.';
$strTransformation_text_plain__link = 'Kuvab lingi, vli sisaldab failinime; esimene seade on eelnev tekst niteks "http://domain.com/", teine seade on nimi lingile.';
$strTransformation_text_plain__substr = 'Nitab ainult osa tekstist. Esimene seade on mrang kust positsioonilt teie teksti kuva hakkab.(vaikimisi 0). Teine seade on kuipalju teksti tagastatakse, kui see thjaks jtta, tagastatakse kogu allesjnud tekst. Kolmas seade defineerib mis tekst lisatakse vljundi lppu kui saadud tekst tagastatakse. (vaikimisi: ...) .';
$strTruncateQueries = 'Lhenda nidatavad pringud';
$strTurkish = 'Trgi';
$strType = 'Tp';

$strUkrainian = 'Ukraina';
$strUncheckAll = 'Puhasta kik';
$strUnicode = 'Unikaalne';
$strUnique = 'Unikaalne';
$strUnknown = 'tundmatu';
$strUnselectAll = 'Puhasta kik';
$strUpdComTab = 'Please see Documentation on how to update your Column_comments Table';
$strUpdatePrivMessage = 'Te uuendasite privileege %s-l.';
$strUpdateProfileMessage = 'Profiil uuendatud.';
$strUpdateQuery = 'Uuenda pringut';
$strUpgrade = 'Te peaksite uuendama %s -i versioonini %s vi uuemaks.';
$strUsage = 'Kasutus';
$strUseBackquotes = 'Kasutage tagurpidi kaldkriipse tabelites vi tabelinimedes';
$strUseHostTable = 'Kasuta host tabelit';
$strUseTabKey = 'Kasutage TAB klahvi, et liikuda helt vrtuselt teisele vi CTRL+nool, et liikuda noole suunas';
$strUseTables = 'Kasuta tabeleid';
$strUseTextField = 'Kasutage tekstivlja';
$strUseThisValue = 'Kasuta seda vrtust';
$strUser = 'Kasutaja';
$strUserAlreadyExists = 'Kasutaja %s on juba olemas!';
$strUserEmpty = 'Kasutajanimi on thi!';
$strUserName = 'Kasutajanimi';
$strUserNotFound = 'Valitud kasutajat ei leitud privileegide tabelist.';
$strUserOverview = 'Kasutaja levaade';
$strUsersDeleted = 'Valitud kasutajad on nnestunult kustutatud.';
$strUsersHavingAccessToDb = 'Kasutajad kellel on ligips &quot;%s&quot;';

$strValidateSQL = 'Kontrolli SQL-i';
$strValidatorError = 'SQL-i valideerijat ei suudetud avada. Palun kontrollige, et te olete installinud vastavad php moodulid nagu on kirjeldatud %sdokumentatsioonis%s.';
$strValue = 'Vrtus';
$strVar = 'Muutuja';
$strVersionInformation = 'Versiooni info';
$strView = 'Vaade';
$strViewDump = 'Vaata tabeli vljundit (skeemi)';
$strViewDumpDB = 'Vaata andmebaasi vljundit (skeemi)';
$strViewDumpDatabases = 'Nita andmebaaside sisu (skeemi)';
$strViewHasBeenDropped = 'Vaade %s on kustutatud';

$strWebServerUploadDirectory = 'webiserveri leslaadimiskataloogi';
$strWebServerUploadDirectoryError = 'Kataloog mille Te leslaadimiseks sttisite ei ole ligipsetav';
$strWelcome = 'Tere tulemast %s';
$strWestEuropean = 'Lne-Euroopa';
$strWildcard = 'metamrk';
$strWindowNotFound = 'Vajaliku sirvija akent ei suudetud uuendada. Vibolla Te olete peaakna sulgenud vi Teie sirvija ei luba akendevahelist suhtlist tnu turvaseadetele.';
$strWithChecked = 'Valitud:';
$strWritingCommentNotPossible = 'Kommentaaride kirjutamine ei ole vimalik.';
$strWritingRelationNotPossible = 'Sltuvuse kirjutamine ei ole vimalik';
$strWrongUser = 'Vale kasutajanimi/parool. Ligips keelatud.';

$strXML = 'XML';

$strYes = 'Jah';

$strZeroRemovesTheLimit = 'Mrkus: Mrkides antud seaded 0 (null) , eemaldate limiidi.';
$strZip = '"zipitud"';

// To translate:

$strBufferPool = 'Buffer Pool';  //to translate
$strBufferPoolActivity = 'Buffer Pool Activity';  //to translate
$strBufferPoolUsage = 'Buffer Pool Usage';  //to translate
$strBufferReadMisses = 'Read misses';  //to translate
$strBufferReadMissesInPercent = 'Read misses in %';  //to translate
$strBufferWriteWaits = 'Write waits';  //to translate
$strBufferWriteWaitsInPercent = 'Write waits in %';  //to translate
$strBusyPages = 'Busy pages';  //to translate

$strDataPages = 'Pages containing data';  //to translate
$strDirtyPages = 'Dirty pages';  //to translate

$strFreePages = 'Free pages';  //to translate

$strHTMLExcel = 'Microsoft Excel 2000';  //to translate
$strHTMLExcelOptions = 'Microsoft Excel 2000 export options';  //to translate
$strHTMLWord = 'Microsoft Word 2000';  //to translate
$strHTMLWordOptions = 'Microsoft Word 2000 export options';  //to translate

$strInnoDBAutoextendIncrement = 'Autoextend increment';  //to translate
$strInnoDBAutoextendIncrementDesc = ' The increment size for extending the size of an autoextending tablespace when it becomes full.';  //to translate
$strInnoDBBufferPoolSize = 'Buffer pool size';  //to translate
$strInnoDBBufferPoolSizeDesc = 'The size of the memory buffer InnoDB uses to cache data and indexes of its tables.';  //to translate
$strInnoDBDataFilePath = 'Data files';  //to translate
$strInnoDBDataHomeDir = 'Data home directory';  //to translate
$strInnoDBDataHomeDirDesc = 'The common part of the directory path for all InnoDB data files.';  //to translate
$strInnoDBPages = 'pages';  //to translate

$strLatchedPages = 'Latched pages';  //to translate

$strPagesToBeFlushed = 'Pages to be flushed';  //to translate

$strReadRequests = 'Read requests';  //to translate

$strSocketProblem = '(or the local MySQL server\'s socket is not correctly configured)';  //to translate

$strWriteRequests = 'Write requests';  //to translate

?>
